<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'English [en]',
	'0_liste' => 'spip-en@rezo.net',
	'0_mainteneur' => 'George Kandalaft (khodr1957@gmail.com)',

	// A
	'access_interface_graphique' => 'Back to the full graphic interface',
	'access_mode_texte' => 'Show the simplified text interface',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modify this article',
	'admin_modifier_auteur' => 'Modify this author',
	'admin_modifier_breve' => 'Modify this news item',
	'admin_modifier_mot' => 'Modify this keyword',
	'admin_modifier_rubrique' => 'Modify this section',
	'admin_recalculer' => 'Re-process this page',
	'afficher_calendrier' => 'Show the calendar',
	'afficher_trad' => 'show translations',
	'alerte_maj_impossible' => '<b>Warning!</b> Failed to update the SQL database to version @version@. This may be due to a permissions problem on the database. Please contact your ISP.',
	'alerte_modif_info_concourante' => 'WARNING: This information has been modified elsewhere. The current value is :',
	'analyse_xml' => 'XML parsing',
	'annuler' => 'Cancel',
	'antispam_champ_vide' => 'Please leave this field empty:',
	'articles_recents' => 'Most recent articles',
	'avis_1_erreur_saisie' => 'Your entry contains an error, please check your information.',
	'avis_archive_incorrect' => 'archive is not a valid SPIP file',
	'avis_archive_invalide' => 'archive file is not valid',
	'avis_attention' => 'CAUTION!',
	'avis_champ_incorrect_type_objet' => 'Invalid field name @name@ for object of type @type@',
	'avis_colonne_inexistante' => 'Column @col@ does not exist',
	'avis_erreur' => 'Error: see below',
	'avis_erreur_connexion' => 'Connection error',
	'avis_erreur_cookie' => 'cookie problem',
	'avis_erreur_fonction_contexte' => 'Programming error. This function cannot be called in this context.',
	'avis_erreur_mysql' => 'SQL error',
	'avis_erreur_sauvegarde' => 'Error in backup (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problem entering the private area',
	'avis_nb_erreurs_saisie' => 'Your entry contains @nb@ errors, please check your information.',

	// B
	'barre_a_accent_grave' => 'Insert a capital A with grave accent',
	'barre_aide' => 'Use the typographic short cuts to refine your layout',
	'barre_e_accent_aigu' => 'Insert a capital E with acute accent',
	'barre_eo' => 'Insert an oe-ligature',
	'barre_eo_maj' => 'Insert a capital EO-ligature',
	'barre_euro' => 'Insert a € symbol',
	'barre_gras' => 'Put in {{bold type}}',
	'barre_guillemets' => 'Place between "double quotes"',
	'barre_guillemets_simples' => 'Place between ‘single quotes’',
	'barre_intertitre' => 'Turn into a {{{subheading}}}',
	'barre_italic' => 'Put in {italics}',
	'barre_lien' => 'Turn into a [hyperlink->http://...]',
	'barre_lien_input' => 'Please enter the link address. You may use either an external URL (http://www.mysite.com) or reference another article on this site by simplying entering its number.',
	'barre_note' => 'Turn into a [[Footnote]]',
	'barre_paragraphe' => 'Create a paragraph',
	'barre_quote' => '<quote>Quote a message</quote>',
	'bouton_changer' => 'Change',
	'bouton_chercher' => 'Search',
	'bouton_choisir' => 'Select',
	'bouton_deplacer' => 'Move',
	'bouton_download' => 'Download',
	'bouton_enregistrer' => 'Save',
	'bouton_radio_desactiver_messagerie_interne' => 'Disable internal messaging',
	'bouton_radio_envoi_annonces' => 'Send editorial announcements',
	'bouton_radio_non_envoi_annonces' => 'Do not send any announcements',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Do not send latest news list',
	'bouton_recharger_page' => 'reload this page',
	'bouton_telecharger' => 'Upload',
	'bouton_upload' => 'Upload',
	'bouton_valider' => 'Submit',

	// C
	'cal_apresmidi' => 'afternoon (p.m.)',
	'cal_jour_entier' => 'entire day',
	'cal_matin' => 'morning (a.m.)',
	'cal_par_jour' => 'daily calendar',
	'cal_par_mois' => 'monthly calendar',
	'cal_par_semaine' => 'weekly calendar',
	'choix_couleur_interface' => 'colour',
	'choix_interface' => 'choice of interface',
	'colonne' => 'Column',
	'confirm_changer_statut' => 'Warning: You are about to change this article’s status. Do you wish to continue?',
	'correcte' => 'correct',

	// D
	'date_aujourdhui' => 'today',
	'date_avant_jc' => 'B.C.',
	'date_dans' => 'in @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'tomorrow',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_heures_minutes_court' => '@h@:@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ at @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ from @heure_debut@ to @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ from @heure_debut@@dtabbr@ to @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'on @nomjour@ @date@',
	'date_fmt_periode' => 'From @date_debut@ to @date_fin@',
	'date_fmt_periode_abbr' => 'From @dtart@@date_debut@@dtabbr@ to @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'From',
	'date_fmt_periode_to' => 'to',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'hours',
	'date_hier' => 'yesterday',
	'date_il_y_a' => '@delai@ ago',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Sunday',
	'date_jour_1_abbr' => 'Sun.',
	'date_jour_1_initiale' => 'S.',
	'date_jour_2' => 'Monday',
	'date_jour_2_abbr' => 'Mon.',
	'date_jour_2_initiale' => 'M.',
	'date_jour_3' => 'Tuesday',
	'date_jour_3_abbr' => 'Tue.',
	'date_jour_3_initiale' => 'T.',
	'date_jour_4' => 'Wednesday',
	'date_jour_4_abbr' => 'Wed.',
	'date_jour_4_initiale' => 'W.',
	'date_jour_5' => 'Thursday',
	'date_jour_5_abbr' => 'Thu.',
	'date_jour_5_initiale' => 'T.',
	'date_jour_6' => 'Friday',
	'date_jour_6_abbr' => 'Fri.',
	'date_jour_6_initiale' => 'F.',
	'date_jour_7' => 'Saturday',
	'date_jour_7_abbr' => 'Sat.',
	'date_jour_7_initiale' => 'S.',
	'date_jours' => 'days',
	'date_minutes' => 'minutes',
	'date_mois' => 'months',
	'date_mois_1' => 'January',
	'date_mois_10' => 'October',
	'date_mois_10_abbr' => 'Oct',
	'date_mois_11' => 'November',
	'date_mois_11_abbr' => 'Nov',
	'date_mois_12' => 'December',
	'date_mois_12_abbr' => 'Dec',
	'date_mois_1_abbr' => 'Jan',
	'date_mois_2' => 'February',
	'date_mois_2_abbr' => 'Feb',
	'date_mois_3' => 'March',
	'date_mois_3_abbr' => 'Mar',
	'date_mois_4' => 'April',
	'date_mois_4_abbr' => 'Apr',
	'date_mois_5' => 'May',
	'date_mois_5_abbr' => 'May',
	'date_mois_6' => 'June',
	'date_mois_6_abbr' => 'Jun',
	'date_mois_7' => 'July',
	'date_mois_7_abbr' => 'Jul',
	'date_mois_8' => 'August',
	'date_mois_8_abbr' => 'Aug',
	'date_mois_9' => 'September',
	'date_mois_9_abbr' => 'Sep',
	'date_saison_1' => 'winter',
	'date_saison_2' => 'spring',
	'date_saison_3' => 'summer',
	'date_saison_4' => 'autumn',
	'date_secondes' => 'seconds',
	'date_semaines' => 'weeks',
	'date_un_mois' => 'month',
	'date_une_heure' => 'hour',
	'date_une_minute' => 'minute',
	'date_une_seconde' => 'second',
	'date_une_semaine' => 'week',
	'dirs_commencer' => ' in order to start installation for real',
	'dirs_preliminaire' => 'Preliminary: <b>Setting up access permissions</b>',
	'dirs_probleme_droits' => 'Problem with access permissions',
	'dirs_repertoires_absents' => '<p><b>The following directories were not found: </b></p><ul>@bad_dirs@.</ul>
  <p>It is possible that this is due to inappropriate lower or upper case letters in directory names.
  Please check that the case of the letters in the names of these directories match what is displayed
  above. If they don’t, correct the directory names using your FTP client.</p>
  <p>Once this is done, you can',
	'dirs_repertoires_suivants' => '<p><b>The following directories do not have write permission: </b></p><ul>@bad_dirs@</ul>
<p>To change this, use your FTP client to set access permissions for each
 of these directories. The procedure is detailed in the installation guide.</p>
  <p>Once you have done this, you can ',
	'double_occurrence' => 'Two instances of @balise@',

	// E
	'en_cours' => 'processing',
	'envoi_via_le_site' => 'Sent via the site',
	'erreur' => 'Error',
	'erreur_balise_non_fermee' => 'last tag not closed:',
	'erreur_technique_ajaxform' => 'Ooops. An unexpected error prevented to submit the form. You can try again.',
	'erreur_technique_enregistrement_champs' => 'A technical error prevented the right registration of the field @champs@.',
	'erreur_technique_enregistrement_impossible' => 'A technical error prevented the registration.',
	'erreur_texte' => 'error(s)',
	'etape' => 'Step',

	// F
	'fichier_introuvable' => 'File not found: @fichier@',
	'form_auteur_confirmation' => 'Please confirm your email address',
	'form_auteur_email_modifie' => 'Your email address has been changed.',
	'form_auteur_envoi_mail_confirmation' => 'A confirmation email has been sent to @email@. You must visit the URL mentioned in the message to validate your email address.',
	'form_auteur_mail_confirmation' => 'Hello,

You have asked to change your email address.
To confirm your new address, you need to connect to
the address below. (Otherwise your request will be ignored.):

    @url@
',
	'form_deja_inscrit' => 'You are already registered.',
	'form_email_non_valide' => 'Your email address is not valid.',
	'form_forum_access_refuse' => 'You no longer have access to this site.',
	'form_forum_bonjour' => 'Hello @nom@,',
	'form_forum_confirmer_email' => 'To confirm your email address, follow this link: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'This email address is already registered. Enter your usual password.',
	'form_forum_identifiant_mail' => 'Your new identifier has just been emailed to you.',
	'form_forum_identifiants' => 'Personal identifiers',
	'form_forum_indiquer_nom_email' => 'Enter your name and email address here. You will receive your personal identifier shortly by email.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(this is an automated message)',
	'form_forum_pass' => 'password:',
	'form_forum_probleme_mail' => 'Mail problem: the identifier could not be sent.',
	'form_forum_voici1' => 'Here are your identifiers. You may now participate on the site
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Here are your identifiers for submitting articles to
the site "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Please enter your email address.',
	'form_indiquer_nom' => 'Please enter your name.',
	'form_indiquer_nom_site' => 'Please enter the name of your site.',
	'form_pet_deja_enregistre' => 'This site is already registered',
	'form_pet_signature_pasprise' => 'Your signature has been ignored.',
	'form_prop_confirmer_envoi' => 'Confirm send',
	'form_prop_description' => 'Description/comment',
	'form_prop_enregistre' => 'Your suggestion has been recorded. It will appear online after being validated by the administrators of this site.',
	'form_prop_envoyer' => 'Send a message',
	'form_prop_indiquer_email' => 'Please enter a valid email address',
	'form_prop_indiquer_nom_site' => 'Please enter the site’s name.',
	'form_prop_indiquer_sujet' => 'Please enter a subject',
	'form_prop_message_envoye' => 'Message sent',
	'form_prop_non_enregistre' => 'Your suggestion has not been recorded.',
	'form_prop_sujet' => 'Subject',
	'form_prop_url_site' => 'Site URL',
	'forum_non_inscrit' => 'Either you are not registered, or the address or password are wrong.',
	'forum_par_auteur' => 'by @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'The site’s backend file for articles is:',
	'ical_texte_rss_articles2' => 'You can also get backend files for individual sections on the site:',
	'ical_texte_rss_breves' => 'Furthermore, there is a file containing the site’s news items. By selecting a section number, you can choose to get news items in that section only.',
	'icone_a_suivre' => 'Launch pad',
	'icone_admin_site' => 'Site administration',
	'icone_agenda' => 'Calendar',
	'icone_aide_ligne' => 'Help',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Authors',
	'icone_brouteur' => 'Quick browsing',
	'icone_configuration_site' => 'Configuration',
	'icone_configurer_site' => 'Configure your site',
	'icone_creer_nouvel_auteur' => 'Create a new author',
	'icone_creer_rubrique' => 'Create a section',
	'icone_creer_sous_rubrique' => 'Create a subsection',
	'icone_deconnecter' => 'Log out',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents attached',
	'icone_ecrire_article' => 'Write a new article',
	'icone_edition_site' => 'Edit site',
	'icone_gestion_langues' => 'Language options',
	'icone_informations_personnelles' => 'Personal information',
	'icone_interface_complet' => 'full interface',
	'icone_interface_simple' => 'Simplified interface',
	'icone_maintenance_site' => 'Site maintenance',
	'icone_messagerie_personnelle' => 'Private messages',
	'icone_repartition_debut' => 'Show distribution from the start',
	'icone_rubriques' => 'Sections',
	'icone_sauver_site' => 'Site backup',
	'icone_site_entier' => 'The entire site',
	'icone_sites_references' => 'Referenced sites',
	'icone_statistiques' => 'Site statistics',
	'icone_suivi_activite' => 'Follow site activity',
	'icone_suivi_actualite' => 'Site statistics',
	'icone_suivi_pettions' => 'Manage petitions',
	'icone_suivi_revisions' => 'Article revisions',
	'icone_supprimer_document' => 'Delete this document',
	'icone_supprimer_image' => 'Delete this image',
	'icone_tous_articles' => 'All your articles',
	'icone_tous_auteur' => 'All authors',
	'icone_tous_visiteur' => 'All visitors',
	'icone_visiter_site' => 'View the public site',
	'icone_voir_en_ligne' => 'View online',
	'img_indisponible' => 'image unavailable',
	'impossible' => 'impossible',
	'info_a_suivre' => 'LAUNCH PAD»',
	'info_acces_interdit' => 'Access forbidden',
	'info_acces_refuse' => 'Access denied',
	'info_action' => 'Action: @action@',
	'info_administrer_rubriques' => 'You can manage this section and any subsections',
	'info_adresse_non_indiquee' => 'You did not specify an address to test!',
	'info_aide' => 'HELP:',
	'info_ajouter_mot' => 'Add keyword',
	'info_annonce' => 'ANNOUNCEMENT',
	'info_annonces_generales' => 'General announcements:',
	'info_article_propose' => 'Article submitted',
	'info_article_publie' => 'Article published',
	'info_article_redaction' => 'Article in progress',
	'info_article_refuse' => 'Article rejected',
	'info_article_supprime' => 'Article deleted',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Articles awaiting validation',
	'info_articles_nb' => '@nb@ articles',
	'info_articles_proposes' => 'Articles submitted',
	'info_articles_un' => '1 article',
	'info_auteurs_nombre' => 'author(s):',
	'info_authentification_ftp' => 'Authentication (by FTP).',
	'info_breves_2' => 'news',
	'info_breves_nb' => '@nb@ news items',
	'info_breves_un' => '1 news item',
	'info_connexion_refusee' => 'Connection denied',
	'info_contact_developpeur' => 'Please contact a developer.',
	'info_contenance' => 'This site contains:',
	'info_contribution' => 'contributions',
	'info_copyright' => '@spip@ is free software distributed @lien_gpl@.',
	'info_copyright_doc' => 'For more visit <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'under the GPL license',
	'info_cours_edition' => 'In progress',
	'info_creer_repertoire' => 'Please create a file or a directory called:',
	'info_creer_repertoire_2' => 'inside the sub-directory <b>@repertoire@</b>, then',
	'info_creer_vignette' => 'automatic thumbnail creation',
	'info_creerdansrubrique_non_autorise' => 'You don’t have sufficient rights to create content in this section',
	'info_deplier' => 'Unfold',
	'info_descriptif_nombre' => 'description(s):',
	'info_description' => 'Description:',
	'info_description_2' => 'Description:',
	'info_dimension' => 'Size:',
	'info_documents_nb' => '@nb@ documents',
	'info_documents_un' => '1 document',
	'info_ecire_message_prive' => 'Write a private message',
	'info_email_invalide' => 'Invalid email address.',
	'info_en_cours_validation' => 'Your articles in progress',
	'info_en_ligne' => 'Online now:',
	'info_envoyer_message_prive' => 'Send a private message to this author',
	'info_erreur_requete' => 'Error in query:',
	'info_erreur_squelette2' => 'No <b>@fichier@</b> template available ...',
	'info_erreur_systeme' => 'System error (errno @errsys@)',
	'info_erreur_systeme2' => 'The hard disk may be full or the database damaged. <br />
<span style="color:red;">Try <a href=\'@script@\'>repairing the database</a>, or contact your service provider.</span>',
	'info_fini' => 'Done!',
	'info_format_image' => 'Image format to be used for vignettes: @gd_formats@.',
	'info_format_non_defini' => 'undefined format',
	'info_grand_ecran' => 'Large display',
	'info_image_aide' => 'HELP',
	'info_image_process_titre' => 'How to create thumbnails',
	'info_impossible_lire_page' => '<b>Error!</b> The page <tt><html>@test_proxy@</html></tt> cannot be viewed through the proxy',
	'info_installation_systeme_publication' => 'Installing publication system...',
	'info_installer_documents' => 'You can automatically install all documents in the folder @upload@.',
	'info_installer_ftp' => 'As an administrator, you can install files via FTP to the folder @upload@ in order to select them directly from here.',
	'info_installer_images' => 'You can install images in the formats JPEG, GIF, and PNG.',
	'info_installer_images_dossier' => 'Install images in folder @upload@ if you want to select them here.',
	'info_interface_complete' => 'full interface',
	'info_interface_simple' => 'Simplified interface',
	'info_joindre_document_article' => 'You can attach the following types of document to your article',
	'info_joindre_document_rubrique' => 'You can add documents of the following types to this section ',
	'info_joindre_documents_article' => 'You can attach documents of the following types to your article:',
	'info_l_article' => 'the article',
	'info_la_breve' => 'the news item',
	'info_la_rubrique' => 'the section',
	'info_langue_principale' => 'Main language for site',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'by @les_auteurs@',
	'info_logo_format_interdit' => 'Only logos in these formats @formats@ are allowed.',
	'info_logo_max_poids' => 'Logos must be less than @maxi@ (this file is @actuel@).',
	'info_mail_fournisseur' => 'you@mailservice.com',
	'info_message_2' => 'MESSAGE',
	'info_message_supprime' => 'MESSAGE DELETED',
	'info_messages_nb' => '@nb@ messages',
	'info_messages_un' => '1 message',
	'info_mise_en_ligne' => 'Published on:',
	'info_modification_parametres_securite' => 'modifying security parameters',
	'info_mois_courant' => 'During the month:',
	'info_mot_cle_ajoute' => 'The following keyword was added to',
	'info_multi_herit' => 'Default language',
	'info_multi_langues_soulignees' => 'The <u>languages underlined</u> provide partial or total translations for all the interface texts. If you select these languages, many elements of the public site (dates, forms) will be translated automatically. As for the languages that are not underlined, those elements will be displayed using the site’s default language.',
	'info_multilinguisme' => 'Multilingual',
	'info_nom_non_utilisateurs_connectes' => 'Your name does not appear in the list of users online.',
	'info_nom_utilisateurs_connectes' => 'Your name appears in the list of users online.',
	'info_nombre_en_ligne' => 'Online now:',
	'info_non_resultat' => 'No results for "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'You are not using private messaging on this site.',
	'info_nouveau_message' => 'YOU HAVE A NEW MESSAGE',
	'info_nouveaux_messages' => 'YOU HAVE @total_messages@ NEW MESSAGES',
	'info_numero_abbreviation' => 'No',
	'info_obligatoire' => 'This information is required',
	'info_pense_bete' => 'MEMO',
	'info_petit_ecran' => 'Small display',
	'info_petition_close' => 'Petition closed',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Several keywords were found for "@cherche_mot@":',
	'info_portfolio_automatique' => 'Automated portfolio:',
	'info_premier_resultat' => '[First @debut_limit@ results out of @total@]',
	'info_premier_resultat_sur' => '[First @debut_limit@ results out of @total@]',
	'info_propose_1' => '[@nom_site_spip@] Submitted: @titre@',
	'info_propose_2' => 'Article submitted
-----------------',
	'info_propose_3' => 'The article "@titre@" has been submitted for publication.',
	'info_propose_4' => 'You are invited to review it and give your opinion',
	'info_propose_5' => 'in the associated forum. It is available here:',
	'info_publie_01' => 'The article "@titre@" was validated by @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLISHED: @titre@',
	'info_publie_2' => 'Article published
-----------------',
	'info_rechercher' => 'Search',
	'info_rechercher_02' => 'Search:',
	'info_remplacer_vignette' => 'Replace the default vignette by a customised logo:',
	'info_rubriques_nb' => '@nb@ sections',
	'info_rubriques_un' => '1 section',
	'info_sans_titre_2' => 'untitled',
	'info_selectionner_fichier' => 'You can select a file from the folder @upload@',
	'info_selectionner_fichier_2' => 'Select a file:',
	'info_sites_nb' => '@nb@ sites',
	'info_sites_un' => '1 site',
	'info_supprimer_vignette' => 'delete the vignette',
	'info_symbole_bleu' => 'A <b>blue</b> symbol indicates a <b>memo</b>: i.e. a message for your personal use.',
	'info_symbole_jaune' => 'A <b>yellow</b> symbol indicates an <b>announcement to all editors</b>: it can be edited by all administrators, and is visible to all editors.',
	'info_symbole_vert' => 'A <b>green</b> symbol indicates the <b>messages exchanged with other users</b> of the site.',
	'info_telecharger_nouveau_logo' => 'Upload a new logo:',
	'info_telecharger_ordinateur' => 'Upload from your computer:',
	'info_tous_resultats_enregistres' => '[all the results are recorded]',
	'info_tout_afficher' => 'Show all',
	'info_travaux_texte' => 'This site is not yet set up. Please come back later...',
	'info_travaux_titre' => 'Site under construction',
	'info_trop_resultat' => 'Too many results for "@cherche_mot@"; please refine the search.',
	'info_utilisation_messagerie_interne' => 'You are using the internal message system of this site.',
	'info_valider_lien' => 'validate this link',
	'info_verifier_image' => ', please make sure your images have been transferred correctly.',
	'info_vignette_defaut' => 'Default vignette',
	'info_vignette_personnalisee' => 'Custom vignette',
	'info_visite' => 'visit:',
	'info_vos_rendez_vous' => 'Your future appointments',
	'infos_vos_pense_bete' => 'Your memos',

	// L
	'label_ajout_id_rapide' => 'Quick addition',
	'label_poids_fichier' => 'Size',
	'lien_afficher_icones_seuls' => 'Show only icons',
	'lien_afficher_texte_icones' => 'Show icons and text',
	'lien_afficher_texte_seul' => 'Show only text',
	'lien_liberer' => 'release',
	'lien_liberer_tous' => 'Release all',
	'lien_nouvea_pense_bete' => 'NEW MEMO',
	'lien_nouveau_message' => 'NEW MESSAGE',
	'lien_nouvelle_annonce' => 'NEW ANNOUNCEMENT',
	'lien_petitions' => 'PETITION',
	'lien_popularite' => 'popularity: @popularite@%',
	'lien_racine_site' => 'SITE ROOT',
	'lien_reessayer' => 'try again',
	'lien_repondre_message' => 'Reply to this message',
	'lien_supprimer' => 'delete',
	'lien_tout_afficher' => 'Show all',
	'lien_visite_site' => 'visit this site',
	'lien_visites' => '@visites@ visits',
	'lien_voir_auteur' => 'Check this author',
	'ligne' => 'Line',
	'login' => 'Connection',
	'login_acces_prive' => 'access to the private area',
	'login_autre_identifiant' => 'use a different ID',
	'login_cookie_accepte' => 'Please configure your browser to accept them for this site.',
	'login_cookie_oblige' => 'For secure identification, your browser must accept cookies.',
	'login_deconnexion_ok' => 'Logged out.',
	'login_erreur_pass' => 'Wrong password.',
	'login_espace_prive' => 'private area',
	'login_identifiant_inconnu' => 'The identifier "@login@" is unknown.',
	'login_login' => 'Login:',
	'login_login2' => 'Login or e-mail address:',
	'login_login_pass_incorrect' => '(Wrong login or password).',
	'login_motpasseoublie' => 'password forgotten?',
	'login_non_securise' => 'Caution, this form is not secure.
   If you do not want your password to be open to
   interception on the network, please activate Javascript
   in your browser and',
	'login_nouvelle_tentative' => 'New attempt',
	'login_par_ici' => 'You are registered... this way...',
	'login_pass2' => 'Password:',
	'login_preferez_refuser' => '<b>If you prefer to refuse cookies</b>, there is another, less secure, method of connection available:',
	'login_recharger' => 'reload this page',
	'login_rester_identifie' => 'Remember my ID for a few days',
	'login_retour_public' => 'Back to the public site',
	'login_retour_site' => 'Back to the public site',
	'login_retoursitepublic' => 'back to the public site',
	'login_sans_cookie' => 'Identification without cookie',
	'login_securise' => 'Secure login',
	'login_sinscrire' => 'register',
	'login_test_navigateur' => 'testing browser/reconnection',
	'login_verifiez_navigateur' => '(However, check that your browser did not memorise your password...)',

	// M
	'masquer_colonne' => 'Hide this column',
	'masquer_trad' => 'hide translations',
	'module_fichiers_langues' => 'Language files',

	// N
	'navigateur_pas_redirige' => 'If you are not automatically redirected, click here to continue.',
	'numero' => 'Number',

	// O
	'occurence' => 'Instance',
	'onglet_affacer_base' => 'Delete the database',
	'onglet_auteur' => 'The author',
	'onglet_contenu_site' => 'Site content',
	'onglet_evolution_visite_mod' => 'Trend in visits',
	'onglet_fonctions_avances' => 'Advanced functions',
	'onglet_informations_personnelles' => 'Personal Information',
	'onglet_interactivite' => 'Interactivity',
	'onglet_messagerie' => 'Messaging',
	'onglet_repartition_rubrique' => 'Distribution by section',
	'onglet_save_restaur_base' => 'Backup/restore the database',
	'onglet_vider_cache' => 'Empty the cache',

	// P
	'pass_choix_pass' => 'Please choose a new password:',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error:</b> you no longer have access to this site.',
	'pass_erreur_code_inconnu' => '<b>Error:</b> this code does not match any visitors with access permission to this site.',
	'pass_erreur_non_enregistre' => '<b>Error :</b> the address <tt>@email_oubli@</tt> is not registered on this site.',
	'pass_erreur_non_valide' => '<b>Error :</b> the e-mail <tt>@email_oubli@</tt> is not valid!',
	'pass_erreur_probleme_technique' => '<b>Error :</b> this e-mail could not be sent due to a technical problem.',
	'pass_espace_prive_bla' => 'The private area of this site is open to
visitors after registration. Once you have registered,
you can review the articles in progress,
submit articles and participate in forums.',
	'pass_forum_bla' => 'You have requested to take part in a forum
reserved for registered visitors.',
	'pass_indiquez_cidessous' => 'Enter the email address with which you
registered. You
will receive an email explaining how you
can retrieve your password.',
	'pass_mail_passcookie' => '(this is an automated message)

To recover your access to the site
@nom_site_spip@ (@adresse_site@)

Please go to the following address:
    @sendcookie@

You can then enter a new password
and log in to the site.
',
	'pass_mot_oublie' => 'Password forgotten',
	'pass_nouveau_enregistre' => 'Your new password has been recorded.',
	'pass_nouveau_pass' => 'New password',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Forgotten password',
	'pass_procedure_changer' => 'In order to change your password, we have to check your identity first. Please enter the e-mail address associated with this account.',
	'pass_quitter_fenetre' => 'Close this window',
	'pass_rappel_login' => 'Reminder: your identifier (login) is "@login@".',
	'pass_recevoir_mail' => 'You will receive an email explaining how you can retrieve your access to the site.',
	'pass_retour_public' => 'Back to the public site',
	'pass_rien_a_faire_ici' => 'Nothing to do here.',
	'pass_vousinscrire' => 'Registering with the site',
	'precedent' => 'previous',
	'previsualisation' => 'Preview',
	'previsualiser' => 'Show preview',

	// R
	'retour' => 'Return',

	// S
	'spip_conforme_dtd' => 'SPIP finds this page to be in compliance with its DOCTYPE:',
	'squelette' => 'template',
	'squelette_inclus_ligne' => 'included template, line',
	'squelette_ligne' => 'template, line',
	'stats_visites_et_popularite' => '@visites@ visits; popularity: @popularite@',
	'suivant' => 'next',

	// T
	'taille_go' => '@taille@ Gb',
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'When you are more familiar with the interface, click on "',
	'texte_actualite_site_2' => 'full interface',
	'texte_actualite_site_3' => '" to make more features available.',
	'texte_creation_automatique_vignette' => 'Automatic creation of preview vignettes is enabled. If you use this form to install,  images in the format(s) @gd_formats@, they will be coupled with a vignette whose maximum size is @taille_preview@ pixels.',
	'texte_documents_associes' => 'The following documents are associated with the article,,
    but they were not directly
    inserted. Depending on the layout of the public site,
    they may appear as attached documents.',
	'texte_erreur_mise_niveau_base' => 'Database error during the upgrade.
      The image <b>@fichier@</b> did not pass (article @id_article@).<p>
   Note this reference carefully, try the upgrade procedure again,
   and check afterwards that the images still appear
      in the articles.',
	'texte_erreur_visiteur' => 'You have tried to enter the private area using an unauthorised login.',
	'texte_inc_auth_1' => 'You used the login
  <b>@auth_login@</b>, but it does not exist in the database.
  Try to',
	'texte_inc_auth_2' => 'reconnect',
	'texte_inc_auth_3' => ', having quit and
  restarted your browser if necessary.',
	'texte_inc_config' => 'Changes made to the options on these pages have a great effect on
  the functioning of the site. You are advised not to make any changes unless you are
 familiar with how SPIP works. <br /><br /><b>In
 general, you are strongly advised
 to let the main webmaster of the site deal with these pages.</b>',
	'texte_inc_meta_1' => 'The system encountered an error when trying to write the file <code>@fichier@</code>. As a site administrator, please',
	'texte_inc_meta_2' => 'verify write permissions',
	'texte_inc_meta_3' => 'of the directory <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'editing in progress',
	'texte_statut_poubelle' => 'to the dustbin',
	'texte_statut_propose_evaluation' => 'submitted for evaluation',
	'texte_statut_publie' => 'published online',
	'texte_statut_refuse' => 'rejected',
	'titre_ajouter_mot_cle' => 'ADD A KEYWORD:',
	'titre_cadre_raccourcis' => 'SHORTCUTS:',
	'titre_changer_couleur_interface' => 'Changing interface colour',
	'titre_image_admin_article' => 'You can administrate this article',
	'titre_image_administrateur' => 'Administrator',
	'titre_image_aide' => 'Help on this item',
	'titre_image_auteur_supprime' => 'Author deleted',
	'titre_image_redacteur' => 'Editor without access',
	'titre_image_redacteur_02' => 'Editor',
	'titre_image_selecteur' => 'Display list',
	'titre_image_visiteur' => 'Visitor',
	'titre_joindre_document' => 'ATTACH A DOCUMENT',
	'titre_mots_cles' => 'KEYWORDS',
	'titre_probleme_technique' => 'Warning: a technical problem (SQL server) is preventing access to this part of the site. Thank you for your patience.',
	'titre_publier_document' => 'PUBLISH A DOCUMENT IN THIS SECTION',
	'titre_signatures_attente' => 'Signatures awaiting validation',
	'titre_signatures_confirmees' => 'Signatures confirmed',
	'titre_statistiques' => 'Site statistics',
	'titre_titre_document' => 'Document title:',
	'todo' => 'to come',
	'trad_definir_reference' => 'Choose "@titre@" as a reference for translations',
	'trad_reference' => '(reference for translations)',

	// Z
	'zbug_balise_b_aval' => ': B tag too late in loop',
	'zbug_balise_inexistante' => 'Tag @balise@ wrongly declared for @from@',
	'zbug_balise_sans_argument' => 'Missing argument in the @balise@ tag',
	'zbug_boucle' => 'loop',
	'zbug_boucle_recursive_undef' => 'undefined recursive loop: @nom@',
	'zbug_calcul' => 'calculation',
	'zbug_champ_hors_boucle' => 'Field @champ@ outside loop',
	'zbug_champ_hors_motif' => 'Field @champ@ outside context @motif@',
	'zbug_code' => 'code',
	'zbug_critere_inconnu' => 'Unknown criterion @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} on a table without atomic primary key',
	'zbug_distant_interdit' => 'External data forbidden',
	'zbug_doublon_table_sans_cle_primaire' => 'Duplicate entries on a table which does not have a simple primary key',
	'zbug_doublon_table_sans_index' => 'Duplicate entries on a table without an index',
	'zbug_erreur_boucle_double' => 'Loop @id@: double definition',
	'zbug_erreur_boucle_fermant' => 'Loop @id@: missing closing tag',
	'zbug_erreur_boucle_syntaxe' => 'Syntax error in loop (BOUCLE)',
	'zbug_erreur_compilation' => 'Compilation error',
	'zbug_erreur_execution_page' => 'Execution error',
	'zbug_erreur_filtre' => 'Undefined filter @filtre@',
	'zbug_erreur_meme_parent' => '{meme_parent} only applies to loops (FORUMS) and (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Error(s) in template',
	'zbug_hors_compilation' => 'Uncompiled',
	'zbug_info_erreur_squelette' => 'Error in the site',
	'zbug_inversion_ordre_inexistant' => 'Reversion of non-existent order',
	'zbug_pagination_sans_critere' => '#PAGINATION tag without {pagination} criterion, or used in a recursive loop',
	'zbug_parametres_inclus_incorrects' => 'Wrong inclusion parameter: @param@',
	'zbug_profile' => 'Calculation time: @time@',
	'zbug_resultat' => 'result',
	'zbug_serveur_indefini' => 'Undefined SQL server',
	'zbug_statistiques' => 'SQL query statistics in order of duration',
	'zbug_table_inconnue' => 'Unknown SQL table "@table@"',
	'zxml_connus_attributs' => 'known attributes',
	'zxml_de' => 'from',
	'zxml_inconnu_attribut' => 'unknown attribute',
	'zxml_inconnu_balise' => 'unknown tag',
	'zxml_inconnu_entite' => 'unknown entity',
	'zxml_inconnu_id' => 'unknown ID',
	'zxml_mais_de' => 'but from',
	'zxml_non_conforme' => 'not true to the principle',
	'zxml_non_fils' => 'is not a child of',
	'zxml_nonvide_balise' => 'tag not empty',
	'zxml_obligatoire_attribut' => 'required attribute absent in',
	'zxml_succession_fils_incorrecte' => 'incorrect child inheritance',
	'zxml_survoler' => 'to see the correct ones, hover with the cursor',
	'zxml_valeur_attribut' => 'attribute value',
	'zxml_vide_balise' => 'empty tag',
	'zxml_vu' => 'seen before'
);

?>
